==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Alle URLs aanpassen',
	'actualiser_toutes_explication' => 'Je kan de URLs opnieuw verwerken.
		Als een URL wijzigt, wordt een nieuwe entry gemaakt (de reeds aanwezige URLs en  
		handmatige gedefinieerde URLs blijven behouden).', # MODIF

	// B
	'bouton_supprimer_url' => 'Deze URL verwijderen',

	// E
	'erreur_arbo_2_segments_max' => 'Je mag niet meer dan twee URL-segmenten gebruiken voor een object',
	'erreur_config_url_forcee' => 'De configuratie van URLs is vastgelegd in bestand <tt>mes_options.php</tt>.',
	'explication_editer' => 'Het geadvanceerde beheer van URLs laat je de URL van een bladzijde van ieder editoriaal object aanpassen en zal de ontwikkeling bijhouden.',

	// I
	'icone_configurer_urls' => 'URLs configureren',
	'icone_controler_urls' => 'Betekenisvolle URLs',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URLs',
	'info_objet' => 'Object',

	// L
	'label_tri_date' => 'Datum',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Nieuwe URL',
	'label_url_minuscules_0' => 'Houd hoofdletters in de titel aan',
	'label_url_minuscules_1' => 'Forceer URLs in onderkasten',
	'label_url_permanente' => 'Vergrendel deze URL (wordt niet veranderd na modificatie van het object)',
	'label_url_sep_id' => 'Scheidingsteken voor nummertoevoeging bij dubbele URLs',
	'label_urls_activer_controle_oui' => 'Activeer geavanceerd beheer van URLs',
	'label_urls_nb_max_car' => 'Maximum aantal tekens',
	'label_urls_nb_min_car' => 'Minimum aantal tekens',
	'liberer_url' => 'Vrijgeven',
	'liste_des_urls' => 'Alle URLs',

	// T
	'texte_type_urls' => 'Hieronder kun je de manier van berekening van de adressen bepalen.',
	'texte_type_urls_attention' => 'Alleen wanneer het bestand @htaccess@ op de juiste manier in de root van de site is opgeslagen, zal dit werken.',
	'texte_urls_nb_max_car' => 'Waneer de titel langer is, wordt hij afgekapt.',
	'texte_urls_nb_min_car' => 'Waneer de titel korter is, wordt zijn nummer toegevoegd.',
	'titre_gestion_des_urls' => 'Beheer van URLs',
	'titre_type_arbo' => 'Arborescente URLs',
	'titre_type_html' => 'URLs met HTML object',
	'titre_type_libres' => 'Vrije URLs',
	'titre_type_page' => 'Pagina URLs',
	'titre_type_propres' => 'Schone URLs',
	'titre_type_propres2' => 'Schone URLs+<tt>.html</tt>',
	'titre_type_propres_qs' => 'Schone URLs in query-string',
	'titre_type_simple' => 'Eenvoudige URLs',
	'titre_type_standard' => 'Traditionele URLs',
	'titre_type_urls' => 'Soort URL adressen',
	'tout_voir' => 'Bekijk alle URLs',

	// U
	'url_ajout_impossible' => 'Een fout is opgetreden. Deze URL kan niet worden geregistreerd',
	'url_ajoutee' => 'De URL is toegevoegd',

	// V
	'verifier_url_nettoyee' => 'De URL is aangepast, je kunt hem eerst controleren.',
	'verrouiller_url' => 'Vergrendelen'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Alle URLs aanpassen',
	'actualiser_toutes_explication' => 'Je kan de URLs opnieuw verwerken.
		Als een URL wijzigt, wordt een nieuwe entry gemaakt (de reeds aanwezige URLs en  
		handmatige gedefinieerde URLs blijven behouden).',

	// B
	'bouton_supprimer_url' => 'Deze URL verwijderen',

	// E
	'erreur_arbo_2_segments_max' => 'Je mag niet meer dan twee URL-segmenten gebruiken voor een object',
	'erreur_config_url_forcee' => 'De configuratie van URLs is vastgelegd in bestand <tt>mes_options.php</tt>.',
	'explication_editer' => 'Het geadvanceerde beheer van URLs laat je de URL van een bladzijde van ieder editoriaal object aanpassen en zal de ontwikkeling bijhouden.',

	// I
	'icone_configurer_urls' => 'URLs configureren',
	'icone_controler_urls' => 'Betekenisvolle URLs',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URLs',
	'info_objet' => 'Object',

	// L
	'label_tri_date' => 'Datum',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Nieuwe URL',
	'label_url_minuscules_0' => 'Houd hoofdletters in de titel aan',
	'label_url_minuscules_1' => 'Forceer URLs in onderkasten',
	'label_url_permanente' => 'Vergrendel deze URL (wordt niet veranderd na modificatie van het object)',
	'label_url_sep_id' => 'Scheidingsteken voor nummertoevoeging bij dubbele URLs',
	'label_urls_activer_controle_oui' => 'Activeer geavanceerd beheer van URLs',
	'label_urls_nb_max_car' => 'Maximum aantal tekens',
	'label_urls_nb_min_car' => 'Minimum aantal tekens',
	'liberer_url' => 'Vrijgeven',
	'liste_des_urls' => 'Alle URLs',

	// T
	'texte_type_urls' => 'Hieronder kun je de manier van berekening van de adressen bepalen.',
	'texte_type_urls_attention' => 'Alleen wanneer het bestand @htaccess@ op de juiste manier in de root van de site is opgeslagen, zal dit werken.',
	'texte_urls_nb_max_car' => 'Waneer de titel langer is, wordt hij afgekapt.',
	'texte_urls_nb_min_car' => 'Waneer de titel korter is, wordt zijn nummer toegevoegd.',
	'titre_gestion_des_urls' => 'Beheer van URLs',
	'titre_type_arbo' => 'Arborescente URLs',
	'titre_type_html' => 'URLs met HTML object',
	'titre_type_libres' => 'Vrije URLs',
	'titre_type_page' => 'Pagina URLs',
	'titre_type_propres' => 'Schone URLs',
	'titre_type_propres2' => 'Schone URLs+<tt>.html</tt>',
	'titre_type_propres_qs' => 'Schone URLs in query-string',
	'titre_type_simple' => 'Eenvoudige URLs',
	'titre_type_standard' => 'Traditionele URLs',
	'titre_type_urls' => 'Soort URL adressen',
	'tout_voir' => 'Bekijk alle URLs',

	// U
	'url_ajout_impossible' => 'Een fout is opgetreden. Deze URL kan niet worden geregistreerd',
	'url_ajoutee' => 'De URL is toegevoegd',

	// V
	'verifier_url_nettoyee' => 'De URL is aangepast, je kunt hem eerst controleren.',
	'verrouiller_url' => 'Vergrendelen'
);

?>
